- Fix bug `#4`_: `xoutil.decorator.meta.flat_decorator`:func: was not
  working in Python 3.

- Deprecate `xoutil.decorator.meta.flat_decorator`:func:.

.. _#4:  https://gitlab.merchise.org/merchise/xoutil/issues/4
